@@ -67,11 +67,11 @@ typedef volatile sig_atomic_t signal_flag_type;
 capture_config_t capture_cfg =
 { 0 };
 
-signal_flag_type sighup_received = 0;
+signal_flag_type sigusr1_received = 0;
 
-void sighup_handler(int signum)
+void sigusr1_handler(int signum)
 {
-    sighup_received = 1;
+    sigusr1_received = 1;
 }
 
 #if defined(WITH_ZLIB)
@@ -104,11 +104,11 @@ capture_init(size_t limit, bool rtp_capture, bool rotate, size_t pcap_buffer_siz
     capture_cfg.paused = 0;
     capture_cfg.sources = vector_create(1, 1);
 
-    // set up SIGHUP handler
+    // set up SIGUSR1 signal handler for pcap dump file rotation
     // the handler will be served by any of the running threads
     // so we just set a flag and check it in dump_packet
     // so it is only acted upon before then next packed will be dumped
-    if (signal(SIGHUP, sighup_handler) == SIG_ERR)
+    if (signal(SIGUSR1, sigusr1_handler) == SIG_ERR)
         exit(EXIT_FAILURE);
 
     // Fixme
@@ -184,7 +184,7 @@ capture_online(const char *dev)
     }
 
     if (pcap_set_promisc(capinfo->handle, 1) != 0) {
-        fprintf(stderr, "Error setting promiscous mode on %s: %s\n", dev, pcap_geterr(capinfo->handle));
+        fprintf(stderr, "Error setting promiscuous mode on %s: %s\n", dev, pcap_geterr(capinfo->handle));
         return 2;
     }
 
@@ -552,6 +552,10 @@ capture_packet_reasm_ip(capture_info_t *capinfo, const struct pcap_pkthdr *heade
         }
     }
 
+    // Check capture length contains more than link layer
+    if (link_hl >= *caplen)
+        return NULL;
+
     while (*size >= sizeof(struct ip)) {
         // Get IP header
         ip4 = (struct ip *) (packet + link_hl);
@@ -901,8 +905,8 @@ capture_ws_check_packet(packet_t *packet)
     size_payload = packet_payloadlen(packet);
     payload = packet_payload(packet);
 
-    // Check we have payload
-    if (size_payload == 0)
+    // Check we have enough payload (base)
+    if (size_payload == 0 || size_payload <= 2)
         return 0;
 
     // Flags && Opcode
@@ -931,8 +935,17 @@ capture_ws_check_packet(packet_t *packet)
             return 0;
     }
 
+    // Check we have enough payload (base + extended payload headers)
+    if ((int32_t) size_payload - ws_off <= 0) {
+        return 0;
+    }
+
     // Get Masking key if mask is enabled
     if (ws_mask) {
+        // Check we have enough payload (base + extended payload headers + mask)
+        if ((int32_t) size_payload - ws_off - 4 <= 0) {
+            return 0;
+        }
         memcpy(ws_mask_key, (payload + ws_off), 4);
         ws_off += 4;
     }
@@ -1026,8 +1039,9 @@ capture_close()
 }
 
 int
-capture_launch_thread(capture_info_t *capinfo)
+capture_launch_thread()
 {
+    capture_info_t *capinfo = NULL;
     //! capture thread attributes
     pthread_attr_t attr;
     pthread_attr_init(&attr);
@@ -1090,6 +1104,10 @@ capture_set_bpf_filter(const char *filter)
 
     // Apply the given filter to all sources
     while ((capinfo = vector_iterator_next(&it))) {
+        //! Only try to validate bpf filter for pcap sources
+        if (!capinfo->ispcap)
+            continue;
+
         //! Check if filter compiles
         if (pcap_compile(capinfo->handle, &capture_cfg.fp, filter, 0, capinfo->mask) == -1)
             return 1;
@@ -1301,8 +1319,8 @@ capture_set_dumper(pcap_dumper_t *dumper, ino_t dump_inode)
 void
 capture_dump_packet(packet_t *packet)
 {
-    if (sighup_received && capture_cfg.pd) {
-        // we got a SIGHUP: reopen the dump file because it could have been renamed
+    if (sigusr1_received && capture_cfg.pd) {
+        // we got a SIGUSR1: reopen the dump file because it could have been renamed
         // we don't need to care about locking or other threads accessing in parallel
         // because dump_open ensures count(capture_cfg.sources) == 1
 
@@ -1316,7 +1334,7 @@ capture_dump_packet(packet_t *packet)
             capture_cfg.pd = dump_open(capture_cfg.dumpfilename, &capture_cfg.dump_inode);
         }
 
-        sighup_received = 0;
+        sigusr1_received = 0;
 
         // error reopening capture file: we can't capture anymore
         if (!capture_cfg.pd)
