@@ -53,7 +53,7 @@
 capture_eep_config_t eep_cfg = { 0 };
 
 void *
-accept_eep_client(void *data);
+accept_eep_client(void *info);
 
 int
 capture_eep_init()
@@ -125,12 +125,6 @@ capture_eep_init()
             return 1;
         }
 
-        // Create a new thread for accepting client connections
-        if (pthread_create(&eep_cfg.server_thread, NULL, accept_eep_client, NULL) != 0) {
-            fprintf(stderr, "Error creating accept thread: %s\n", strerror(errno));
-            return 1;
-        }
-
         capture_info_t *capinfo;
 
         // Create a new structure to handle this capture source
@@ -139,6 +133,10 @@ capture_eep_init()
             return 1;
         }
 
+        // Set capture thread function
+        capinfo->capture_fn = accept_eep_client;
+        capinfo->ispcap = false;
+
         // Open capture device
         capinfo->handle = pcap_open_dead(DLT_EN10MB, MAXIMUM_SNAPLEN);
 
@@ -165,9 +163,10 @@ capture_eep_init()
 
 
 void *
-accept_eep_client(void *data)
+accept_eep_client(void *info)
 {
     packet_t *pkt;
+    capture_info_t *capinfo = (capture_info_t *) info;
 
     // Begin accepting connections
     while (eep_cfg.server_sock > 0) {
@@ -182,6 +181,9 @@ accept_eep_client(void *data)
         }
     }
 
+    // Mark capture as not longer running
+    capinfo->running = false;
+
     // Leave the thread gracefully
     pthread_exit(NULL);
     return 0;
@@ -196,7 +198,6 @@ capture_eep_deinit()
     if (eep_cfg.server_sock) {
         close(eep_cfg.server_sock);
         eep_cfg.server_sock = -1;
-        //pthread_join(&eep_cfg.server_thread, &ret);
     }
 }
 
@@ -594,8 +595,8 @@ capture_eep_receive_v2()
     //! New created packet pointer
     packet_t *pkt;
     //! EEP client data
-    struct sockaddr eep_client;
-    socklen_t eep_client_len;
+    struct sockaddr_storage eep_client;
+    socklen_t eep_client_len=sizeof(eep_client);
     struct hep_hdr hdr;
     struct hep_timehdr hep_time;
     struct hep_iphdr hep_ipheader;
@@ -610,7 +611,7 @@ capture_eep_receive_v2()
     memset(buffer, 0, MAX_CAPTURE_LEN);
 
     /* Receive EEP generic header */
-    if (recvfrom(eep_cfg.server_sock, buffer, MAX_CAPTURE_LEN, 0, &eep_client, &eep_client_len) == -1)
+    if (recvfrom(eep_cfg.server_sock, buffer, MAX_CAPTURE_LEN, 0, (struct sockaddr*)&eep_client, &eep_client_len) == -1)
         return NULL;
 
     /* Copy initial bytes to HEPv2 header */
@@ -674,6 +675,12 @@ capture_eep_receive_v2()
     packet_set_type(pkt, PACKET_SIP_UDP);
     packet_set_payload(pkt, payload, header.caplen);
 
+    // We don't longer require frame payload anymore, because adding the frame to packet clones its memory
+    sng_free(frame_payload);
+
+    // Store this packets in output file
+    capture_dump_packet(pkt);
+
     /* FREE */
     sng_free(payload);
     return pkt;
@@ -709,8 +716,8 @@ capture_eep_receive_v3(const u_char *pkt, uint32_t size)
     //! Source and Destination Address
     address_t src, dst;
     //! EEP client data
-    struct sockaddr eep_client;
-    socklen_t eep_client_len;
+    struct sockaddr_storage eep_client;
+    socklen_t eep_client_len=sizeof(eep_client);
     //! Packet header
     struct pcap_pkthdr header;
     //! New created packet pointer
@@ -721,7 +728,7 @@ capture_eep_receive_v3(const u_char *pkt, uint32_t size)
 
     if(!pkt) {
         /* Receive EEP generic header */
-        if (recvfrom(eep_cfg.server_sock, buffer, MAX_CAPTURE_LEN, 0, &eep_client, &eep_client_len) == -1)
+        if (recvfrom(eep_cfg.server_sock, buffer, MAX_CAPTURE_LEN, 0, (struct sockaddr*)&eep_client, &eep_client_len) == -1)
             return NULL;
     } else {
         memcpy(&buffer, pkt, size);
@@ -853,6 +860,12 @@ capture_eep_receive_v3(const u_char *pkt, uint32_t size)
     packet_set_type(pkt_new, PACKET_SIP_UDP);
     packet_set_payload(pkt_new, payload, header.caplen);
 
+    // We don't longer require frame payload anymore, because adding the frame to packet clones its memory
+    sng_free(frame_payload);
+
+    // Store this packets in output file
+    capture_dump_packet(pkt_new);
+
     /* FREE */
     sng_free(payload);
     return pkt_new;
