@@ -428,7 +428,7 @@ call_flow_draw_message(ui_t *ui, call_flow_arrow_t *arrow, int cline)
     address_t dst;
     char method[METHOD_MAXLEN + 1];
     char delta[15] = {};
-    int flowh, floww;
+    int flowh;
     char mediastr[40];
     sip_msg_t *msg = arrow->item;
     vector_iter_t medias;
@@ -444,7 +444,7 @@ call_flow_draw_message(ui_t *ui, call_flow_arrow_t *arrow, int cline)
 
     // Get the messages window
     flow_win = info->flow_win;
-    getmaxyx(flow_win, flowh, floww);
+    flowh = getmaxx(flow_win);
 
     // Store arrow start line
     arrow->line = cline;
@@ -673,7 +673,7 @@ call_flow_draw_rtp_stream(ui_t *ui, call_flow_arrow_t *arrow, int cline)
     call_flow_info_t *info;
     WINDOW *win;
     char text[50], time[20];
-    int height, width;
+    int height;
     rtp_stream_t *stream = arrow->item;
     sip_msg_t *msg;
     sip_call_t *call;
@@ -684,7 +684,7 @@ call_flow_draw_rtp_stream(ui_t *ui, call_flow_arrow_t *arrow, int cline)
     info = call_flow_info(ui);
     // Get the messages window
     win = info->flow_win;
-    getmaxyx(win, height, width);
+    height = getmaxy(win);
 
     // Store arrow start line
     arrow->line = cline;
@@ -1107,7 +1107,7 @@ call_flow_draw_raw_rtcp(ui_t *ui, rtp_stream_t *stream)
 int
 call_flow_handle_key(ui_t *ui, int key)
 {
-    int raw_width, height, width;
+    int raw_width;
     call_flow_info_t *info = call_flow_info(ui);
     ui_t *next_ui;
     sip_call_t *call = NULL, *xcall = NULL;
@@ -1118,8 +1118,6 @@ call_flow_handle_key(ui_t *ui, int key)
     if (!info)
         return KEY_NOT_HANDLED;
 
-    getmaxyx(info->flow_win, height, width);
-
     // Check actions for this key
     while ((action = key_find_action(key, action)) != ERR) {
         // Check if we handle this action
