@@ -592,9 +592,9 @@ dialog_progress_run(const char *fmt, ...)
 void
 dialog_progress_set_value(WINDOW *win, int perc)
 {
-    int height, width;
+    int width;
 
-    getmaxyx(win, height, width);
+    width = getmaxx(win);
     mvwhline(win, 4, 4, '-', width - 10);
     mvwaddch(win, 4, 3, '[');
     mvwaddch(win, 4, width - 7, ']');
